@@ -53,8 +53,8 @@ CREATE_XML = u"""<?xml version="1.0" encoding="utf-8"?>
                <dPesoOri>%(origin_weight)s</dPesoOri>
                <boInsert>%(insert)s</boInsert>
                <strRef>%(reference)s</strRef>
-               <boDesEmail>%(email_notification)</boDesEmail>
-               <strDesDirEmails>%(email)</strDesDirEmails>
+               <boDesEmail>%(email_notification)s</boDesEmail>
+               <strDesDirEmails>%(email)s</strDesDirEmails>
            </WebServService___GrabaEnvio4>
        </soap:Body>
     </soap:Envelope>"""
